@@ -7,8 +7,8 @@ class Brain:
 
     def __init__(self, mode=0):
         self.modeSwitcher = {
-            0: ConfigEnum.CNN_DEFAULT_MODEL.value,
-            1: ConfigEnum.CNN_30MIN_MODEL.value
+            0: ConfigEnum.get("CNN_DEFAULT_MODEL"),
+            1: ConfigEnum.get("CNN_30MIN_MODEL")
         }
         self.model = None
         self.init(self.modeSwitcher[mode])
