@@ -30,7 +30,7 @@ class Image:
 
     def resize(self,image):
         image = np.uint8(image)
-        image = PilImage.fromarray(image).resize((ConfigEnum.IMAGE_WIDTH.value,ConfigEnum.IMAGE_HEIGHT.value))
+        image = PilImage.fromarray(image).resize((ConfigEnum.get("IMAGE_WIDTH"), ConfigEnum.get("IMAGE_HEIGHT")))
         return np.array(image)
 
     def normalize(self, image):
